@@ -1,6 +1,5 @@
 #This file is part of Tryton.  The COPYRIGHT file at the top level
 #of this repository contains the full copyright notices and license terms.
-import time
 import datetime
 from decimal import Decimal, ROUND_HALF_EVEN
 from trytond.model import ModelView, ModelSQL, fields
@@ -21,15 +20,15 @@ class Currency(ModelSQL, ModelView):
         on_change_with=['rates']), 'get_rate')
     rates = fields.One2Many('currency.currency.rate', 'currency', 'Rates')
     rounding = fields.Numeric('Rounding factor', digits=(12, 6), required=True)
-    digits = fields.Integer('Display Digits')
+    digits = fields.Integer('Display Digits', required=True)
     active = fields.Boolean('Active')
 
     # monetary formatting
     mon_grouping = fields.Char('Grouping', required=True)
     mon_decimal_point = fields.Char('Decimal Separator', required=True)
     mon_thousands_sep = fields.Char('Thousands Separator')
-    p_sign_posn = fields.Integer('Positive Sign Position')
-    n_sign_posn = fields.Integer('Negative Sign Position')
+    p_sign_posn = fields.Integer('Positive Sign Position', required=True)
+    n_sign_posn = fields.Integer('Negative Sign Position', required=True)
     positive_sign = fields.Char('Positive Sign')
     negative_sign = fields.Char('Negative Sign')
     p_cs_precedes = fields.Boolean('Positive Currency Symbol Precedes')
@@ -205,13 +204,10 @@ class Currency(ModelSQL, ModelView):
             else:
                 name = to_currency.name
 
-            for code in [Transaction().language, 'en_US']:
-                lang_ids = lang_obj.search([
-                    ('code', '=', code),
+            lang_id, = lang_obj.search([
+                    ('code', '=', Transaction().language),
                     ])
-                if lang_ids:
-                    break
-            lang = lang_obj.browse(lang_ids[0])
+            lang = lang_obj.browse(lang_id)
 
             self.raise_user_error('no_rate', (name,
                 datetime_strftime(date, str(lang.date))))
@@ -229,7 +225,7 @@ class Rate(ModelSQL, ModelView):
     _name = 'currency.currency.rate'
     _description = __doc__
     _rec_name = 'date'
-    date = fields.Date('Date', required=True, select=1)
+    date = fields.Date('Date', required=True, select=True)
     rate = fields.Numeric('Rate', digits=(12, 6), required=1)
     currency = fields.Many2One('currency.currency', 'Currency',
             ondelete='CASCADE',)
@@ -239,6 +235,8 @@ class Rate(ModelSQL, ModelView):
         self._sql_constraints = [
             ('date_currency_uniq', 'UNIQUE(date, currency)',
                 'A currency can only have one rate by date!'),
+            ('check_currency_rate', 'CHECK(rate >= 0)',
+                'The currency rate must greater than or equal to 0'),
         ]
         self._order.insert(0, ('date', 'DESC'))
 
@@ -250,4 +248,3 @@ class Rate(ModelSQL, ModelView):
         return True
 
 Rate()
-
